@@ -48,10 +48,8 @@ aghui::SExpDesignUI::construct_widgets()
 				    G_TYPE_POINTER);
 
       // misc
-	//monofont = pango_font_description_new();
-	//pango_font_description_set_family_static( monofont, "Monospace");
+	auto font_desc = pango_font_description_from_string( "Mono 9");
 
-	//GtkStyle* sty;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *col;
 
@@ -337,7 +335,10 @@ aghui::SExpDesignUI::construct_widgets()
 	if ( !(AGH_GBGETOBJ (GtkDialog,		wScanLog)) ||
 	     !(AGH_GBGETOBJ (GtkTextView,	tScanLog)) )
 		return -1;
-	gtk_widget_get_style( (GtkWidget*)tScanLog) -> font_desc = monofont;
+
+	gtk_widget_override_font( (GtkWidget*)tScanLog, font_desc);
+	gtk_widget_override_font( (GtkWidget*)tREADME, font_desc);
+	// free? unref? leak some?
 
 	char *contents;
 	snprintf_buf( "%s/doc/%s/README", PACKAGE_DATADIR, PACKAGE);
@@ -524,7 +525,9 @@ aghui::SExpDesignUI::construct_widgets()
 			  this);
 
       // ------ colours
-	if ( !(CwB[TColour::power_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPowerMT")) ||
+	if ( !(CwB[TColour::night	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNight")) ||
+	     !(CwB[TColour::day		].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourDay")) ||
+	     !(CwB[TColour::power_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPowerMT")) ||
 	     !(CwB[TColour::ticks_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksMT")) ||
 	     !(CwB[TColour::labels_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsMT")) ||
 
@@ -582,9 +585,10 @@ aghui::SExpDesignUI::construct_widgets()
 	g_object_set( lEDFFileDetailsReport,
 		      "tabs", pango_tab_array_new_with_positions(
 			      2, TRUE,
-			      PANGO_TAB_LEFT, 130,
+			      PANGO_TAB_LEFT, 180,
 			      PANGO_TAB_LEFT, 190),
 		      NULL);
+	gtk_widget_override_font( (GtkWidget*)lEDFFileDetailsReport, font_desc);
 
       // ------- wEdfImport
 	if ( !AGH_GBGETOBJ (GtkDialog,		wEdfImport) ||
@@ -690,6 +694,8 @@ aghui::SExpDesignUI::construct_widgets()
 						     "text", 0,
 						     NULL);
 
+	pango_font_description_free( font_desc);
+
 	return 0;
 }
 
